#!/usr/bin/env ruby

require 'qte'
require 'qpe'
require "timeout"
require "date"
require "open-uri"
require "rexml/document"
require 'ping'
require "rbuconv"

include Qte
include Qpe

$APPLICATION_NAME = "yahoonewsTTR"

class BerryBaseWidget < QWidget
	def initialize(parent)
			super(parent)
	end

	def close()
		return true
	end

	def showing()
	end

	def repaintFont(font)
	end

	def getWidgetName()
		return ""
	end
end

class Berry < QWidget
	WIDGET_COUNT = 2
	RSS_LIST_WIDGET_ID = 0
	RSS_DESC_VIEW_WIDGET_ID = 1

	def initialize()
		super()
		catchEvent()
		
		setCaption($APPLICATION_NAME)

		
		@widgetStack = QWidgetStack.new(self)
		@rssListWidget = BerryRSSListWidget.new(self)
		@rssDescViewWidget = BerryRSSDescViewWidget.new(self)
		@widgetStack.addWidget(@rssListWidget, RSS_LIST_WIDGET_ID)
		@widgetStack.addWidget(@rssDescViewWidget, RSS_DESC_VIEW_WIDGET_ID)
		
		@verticalLayout = QVBoxLayout.new(self)
		@verticalLayout.addWidget(@widgetStack, 1)
		
		@commMode = false
		@recentWidgetId = nil
		
		changeScreen(RSS_LIST_WIDGET_ID)
	end

	def changeScreen(id)
		@recentWidetId = @currentWidgetId
		@currentWidgetId = id
		@widgetStack.raiseWidget(@currentWidgetId)
		getWidget(id).showing()
		if getWidget(id).getWidgetName() != "" then
			setCaption(tr("#{$APPLICATION_NAME} - #{getWidget(id).getWidgetName()}"))
		else
			setCaption(tr("#{$APPLICATION_NAME}"))
		end
	end
	
	def getRecentWidgetId()
		return @recentWidgetId
	end
	
	def getWidget(id)
		if id == RSS_LIST_WIDGET_ID then
			return @rssListWidget
		end
		if id == RSS_DESC_VIEW_WIDGET_ID then
			return @rssDescViewWidget
		end
		return nil
	end
	
	def closeEvent(event)
		if (getWidget(@currentWidgetId).close()) then
			event.accept()
		end
	end
end

class BerryRSSListWidget < BerryBaseWidget
	def initialize(parent)
		super(parent)
		
		@parent = parent
		
		setCaption(QString::fromUtf8("YahoonewsTTR"))
		bg = QVButtonGroup.new(self)
		bg.setGeometry(0,0,638,150)

		@yhpath = "/home/samba/SD_Card/Documents/Image_Files/"
		@yhpathset = "/home/zaurus/Settings/"

		if (!FileTest.exist?(@yhpathset + "yhttr.xml"))
			$yhpaths = "/home/samba/SD_Card/Documents/Image_Files/"
			$yhpathm = "/home/zaurus/Documents/Image_Files/"
			$yhpathc = "/home/samba/CF_Card/Documents/Image_Files/"
			$kaisouchr = "."
			$n1m = "false"
			$n2m = "false"
			$n3m = "false"
			$n4m = "false"
		end

		if QPEApplication.desktop.width == 640 then
			$slc = true
		else
			$slc = false
		end

		@Menu = QPopupMenu.new()
		@ms = @Menu.insertItem(QString::fromUtf8("取得開始"), self, "getyahoo", CTRL+Key_G)
		@mo = @Menu.insertItem(QString::fromUtf8("お好み取得開始"), self, "getyahoo2", CTRL+Key_F)
		@me = @Menu.insertItem(QString::fromUtf8("取得中止"), self, "stopgetyahoo", CTRL+Key_S)
		@Menu.setItemEnabled(@me,false)
		@Menu.insertItem(QString::fromUtf8("TTexttReaderで開く"), self, "runttr", CTRL+Key_J)
		@Menu.insertItem(QString::fromUtf8("TTexttReaderで開く(高速)"), self, "runttrk", CTRL+Key_K)
		@Menu.insertItem(QString::fromUtf8("お好みリストを開く"), self, "okonomi", CTRL+Key_B)
		@setting1 = QPopupMenu.new()
		@setting1.insertItem(QString::fromUtf8("スポーツ"), self, "cateset1", CTRL+Key_Q)
		@setting1.insertItem(QString::fromUtf8("経済総合"), self, "cateset2", CTRL+Key_W)
		@setting1.insertItem(QString::fromUtf8("株式"), self, "cateset3", CTRL+Key_E)
		@setting1.insertItem(QString::fromUtf8("社会"), self, "cateset4", CTRL+Key_R)
		@setting1.insertItem(QString::fromUtf8("政治"), self, "cateset5", CTRL+Key_T)
		@setting1.insertItem(QString::fromUtf8("海外"), self, "cateset6", CTRL+Key_Y)
		@setting1.insertItem(QString::fromUtf8("市況"), self, "cateset7", CTRL+Key_U)
		@setting1.insertItem(QString::fromUtf8("産業"), self, "cateset8", CTRL+Key_I)
		@setting1.insertItem(QString::fromUtf8("エンターテーメント"), self, "cateset9", CTRL+Key_O)
		@setting1.insertItem(QString::fromUtf8("コンピュータ"), self, "cateset10", CTRL+Key_P)

		@setting1.insertItem(QString::fromUtf8("アクセスランキング　総合"), self, "catesetr1", CTRL+Key_1)
		@setting1.insertItem(QString::fromUtf8("アクセスランキング　スポーツ"), self, "catesetr2", CTRL+Key_2)
		@setting1.insertItem(QString::fromUtf8("アクセスランキング　経済総合"), self, "catesetr3", CTRL+Key_3)
		@setting1.insertItem(QString::fromUtf8("アクセスランキング　国内"), self, "catesetr4", CTRL+Key_4)
		@setting1.insertItem(QString::fromUtf8("アクセスランキング　海外"), self, "catesetr5", CTRL+Key_5)
		@setting1.insertItem(QString::fromUtf8("アクセスランキング　エンターテーメント"), self, "catesetr6", CTRL+Key_6)
		@setting1.insertItem(QString::fromUtf8("アクセスランキング　コンピュータ"), self, "catesetr7", CTRL+Key_7)
		@setting1.insertItem(QString::fromUtf8("個別記事"), self, "cateset11", CTRL+Key_L)
		@setting1.insertItem(QString::fromUtf8("日付指定"), self, "cateset0", CTRL+Key_A)
		@setting2 = QPopupMenu.new()
		@setting2.insertItem(QString::fromUtf8("新規保存"), self, "onradio1", CTRL+Key_N)
		@setting2.insertItem(QString::fromUtf8("上書き保存"), self, "onradio2", CTRL+Key_M)
		@md = @setting2.insertItem(QString::fromUtf8("各種設定"), self, "savedirectory", CTRL+Key_D)
		@menuBar = QPEMenuBar.new(self)
		@menuBar.insertItem(tr("Menu"), @Menu)
		@menuBar.insertItem(QString::fromUtf8("カテゴリー"), @setting1)
		@menuBar.insertItem(QString::fromUtf8("設定"), @setting2)


		bg.setTitle(QString::fromUtf8("Yahoo!ニュース　取得カテゴリ設定"))

		@l6 = QLabel.new(QString::fromUtf8("各カテゴリの取得記事数(1-100)"),self)
		@l1 = QLineEdit.new("25",self)

		@r1 = QRadioButton.new(QString::fromUtf8("新規"),self)
		@r2 = QRadioButton.new(QString::fromUtf8("上書き"),self)
		@r1.setChecked(true)

		@m1 = QComboBox.new(self)

		@m1.insertItem("SD")
		@m1.insertItem(QString::fromUtf8("本体"))
		@m1.insertItem("CF")


		@tw = QTabWidget.new(self)
		@tw.setGeometry(10,55,310,255)

		@w0 = QWidget.new(self)
		@w1 = QWidget.new(self)

		@tw.addTab(@w0,QString::fromUtf8("カテゴリ"))
		@tw.addTab(@w1,QString::fromUtf8("アクセスランキング"))

		@c1 = QCheckBox.new(QString::fromUtf8("Q.スポーツ"),@w0)
		@c2 = QCheckBox.new(QString::fromUtf8("W.経済総合"),@w0)
		@c3 = QCheckBox.new(QString::fromUtf8("E.株式"),@w0)
		@c4 = QCheckBox.new(QString::fromUtf8("R.社会"),@w0)
		@c5 = QCheckBox.new(QString::fromUtf8("T.政治"),@w0)

		@c6 = QCheckBox.new(QString::fromUtf8("Y.海外"),@w0)
		@c7 = QCheckBox.new(QString::fromUtf8("U.市況"),@w0)
		@c8 = QCheckBox.new(QString::fromUtf8("I.産業"),@w0)
		@c9 = QCheckBox.new(QString::fromUtf8("O.エンターテーメント"),@w0)
		@c10 = QCheckBox.new(QString::fromUtf8("P.コンピュータ"),@w0)


		@cr1 = QCheckBox.new(QString::fromUtf8("1.総合"),@w1)
		@cr2 = QCheckBox.new(QString::fromUtf8("2.スポーツ"),@w1)
		@cr3 = QCheckBox.new(QString::fromUtf8("3.経済総合"),@w1)
		@cr4 = QCheckBox.new(QString::fromUtf8("4.国内"),@w1)

		@cr5 = QCheckBox.new(QString::fromUtf8("5.海外"),@w1)
		@cr6 = QCheckBox.new(QString::fromUtf8("6.エンターテーメント"),@w1)
		@cr7 = QCheckBox.new(QString::fromUtf8("7.コンピュータ"),@w1)

		@c11 = QCheckBox.new(QString::fromUtf8("L.個別設定"),self)

		@e2 = QMultiLineEdit.new(self)

		@c0 = QCheckBox.new(QString::fromUtf8("A.日付指定"),self)
		day = Date.today
		@date = day.to_s.sub(/-/,"").sub(/-/,"")
		@l0 = QLineEdit.new(@date,self)

		@m = QPushButton.new(QString::fromUtf8("取得開始( Ctrl + G )"),self)
		@m4 = QPushButton.new(QString::fromUtf8("お好み取得開始( Ctrl + F )"),self)
		@m3 = QPushButton.new(QString::fromUtf8("取得中止( Ctrl + S )"),self)
		@m3.setEnabled(false)

		@m2 = QPushButton.new(QString::fromUtf8("TTexttReaderで開く"),self)
		@l2 = QLabel.new(QString::fromUtf8("status"),self)
		@e1 = QLineEdit.new("",self)

		@e1.setReadOnly(true)

		if $slc then
			bg.setGeometry(0,30,639,465)
			@l6.setGeometry(330,50,200,30)
			@l1.setGeometry(510,50,30,30)
			@r1.setGeometry(330,90,120,30)
			@r2.setGeometry(405,90,120,30)
			@m1.setGeometry(555,50,70,30)

			@c1.setGeometry(10,15,130,30)	
			@c2.setGeometry(10,55,130,30)
			@c3.setGeometry(10,95,130,30)
			@c4.setGeometry(10,135,130,30)
			@c5.setGeometry(10,175,130,30)
			@c6.setGeometry(150,15,130,30)
			@c7.setGeometry(150,55,130,30)
			@c8.setGeometry(150,95,130,30)
			@c9.setGeometry(150,135,170,30)
			@c10.setGeometry(150,175,170,30)

			@cr1.setGeometry(10,15,130,30)
			@cr2.setGeometry(10,55,130,30)
			@cr3.setGeometry(10,95,130,30)
			@cr4.setGeometry(10,135,130,30)
			@cr5.setGeometry(10,175,130,30)
			@cr6.setGeometry(150,15,170,30)
			@cr7.setGeometry(150,55,170,30)
	
			@c11.setGeometry(330,123,130,30)
			@e2.setGeometry(330,155,290,120)
			@l0.setGeometry(470,280,80,30)
			@c0.setGeometry(330,280,130,30)
	
			@m.setGeometry(10,315,200,40)
			@m4.setGeometry(220,315,200,40)
			@m3.setGeometry(430,315,200,40)
	
			@m2.setGeometry(495,90,130,30)
			@l2.setGeometry(10,365,300,30)
			@e1.setGeometry(75,365,555,30)
		else

			@l6 = QLabel.new(QString::fromUtf8("取得記事数(1-100)"),self)
			@m = QPushButton.new(QString::fromUtf8("取得開始( Ctrl+G )"),self)
			@m4 = QPushButton.new(QString::fromUtf8("お好み取得開始( Ctrl+F )"),self)
			@m3 = QPushButton.new(QString::fromUtf8("取得中止( Ctrl+S )"),self)
			bg.setGeometry(0,30,475,590)
			@l6.setGeometry(325,55,100,30)
			@l1.setGeometry(430,55,30,30)
			@r1.setGeometry(325,95,100,30)
			@r2.setGeometry(385,95,70,30)
			@m1.setGeometry(325,135,70,30)
	
			@c1.setGeometry(10,15,130,30)	
			@c2.setGeometry(10,55,130,30)
			@c3.setGeometry(10,95,130,30)
			@c4.setGeometry(10,135,130,30)
			@c5.setGeometry(10,175,130,30)
			@c6.setGeometry(150,15,130,30)
			@c7.setGeometry(150,55,130,30)
			@c8.setGeometry(150,95,130,30)
			@c9.setGeometry(150,135,170,30)
			@c10.setGeometry(150,175,170,30)

			@cr1.setGeometry(10,15,130,30)
			@cr2.setGeometry(10,55,130,30)
			@cr3.setGeometry(10,95,130,30)
			@cr4.setGeometry(10,135,130,30)
			@cr5.setGeometry(10,175,130,30)
			@cr6.setGeometry(150,15,170,30)
			@cr7.setGeometry(150,55,170,30)
	
			@c11.setGeometry(10,313,130,30)
			@e2.setGeometry(10,353,460,100)
			@l0.setGeometry(250,313,80,30)
			@c0.setGeometry(150,313,130,30)
	
			@m.setGeometry(10,460,150,40)
			@m4.setGeometry(165,460,150,40)
			@m3.setGeometry(320,460,150,40)
	
			@m2.setGeometry(325,175,130,30)
			@l2.setGeometry(10,500,300,20)
			@e1.setGeometry(10,525,460,30)

		end
	
		load(@yhpathset + "yhttr.xml")

		@yh_proxy = "" #"http://proxy.toshiba.co.jp:8080/"
	#	URI.parse("http://proxy.toshiba.co.jp:8080/")
		#@kaisouchr = "."

		connect(@m,QSIGNAL("clicked()"), self, 'getyahoo')
		connect(@m4,QSIGNAL("clicked()"), self, 'getyahoo2')
		connect(@m3,QSIGNAL("clicked()"), self, 'stopgetyahoo')
		connect(@m2,QSIGNAL("clicked()"), self, 'runttr')
		connect(@r1,QSIGNAL("clicked()"), self, 'offradio1')
		connect(@r2,QSIGNAL("clicked()"), self, 'offradio2')

		$option = ARGV[0]
		$netop  = ARGV[1]
		if ( $option =~ /run/ ) then
			getyahoo
		end
	end

	def pathset
		case @m1.currentItem.to_i
		when 0
			if ($n3m =~ /true/) then
				if @r1.isChecked then
					@yhpath = $yhpaths + @date + "/"
				else
					@yhpath = $yhpaths + @sdate + "/"
				end
			else
				@yhpath = $yhpaths
			end
		when 1
			if ($n3m =~ /true/) then
				if @r1.isChecked then
					@yhpath = $yhpathm + @date + "/"
				else
					@yhpath = $yhpathm + @sdate + "/"
				end
			else
				@yhpath = $yhpathm
			end
		when 2
			if ($n3m =~ /true/) then
				if @r1.isChecked then
					@yhpath = $yhpathc + @date + "/"
				else
					@yhpath = $yhpathc + @sdate + "/"
				end
			else
				@yhpath = $yhpathc
			end	
		end
	end

	def pathset2
		case @m1.currentItem.to_i
		when 0
			if ($n3m =~ /true/) then
				if @r1.isChecked then
					@yhpath2 = $yhpaths + @date + "/"
				else
					@yhpath2 = $yhpaths + @sdate + "/"
				end
			else
				@yhpath2 = $yhpaths
			end
		when 1
			if ($n3m =~ /true/) then
				if @r1.isChecked then
					@yhpath2 = $yhpathm + @date + "/"
				else
					@yhpath2 = $yhpathm + @sdate + "/"
				end
			else
				@yhpath2 = $yhpathm
			end
		when 2
			if ($n3m =~ /true/) then
				if @r1.isChecked then
					@yhpath2 = $yhpathc + @date + "/"
				else
					@yhpath2 = $yhpathc + @sdate + "/"
				end
			else
				@yhpath2 = $yhpathc
			end	
		end
	end

	def runttr
		pathset2

		begin
			system("qcop QPE/Application/TTextReader 'openEuc(QString)' " + @yhpath2 + "yahoo_news.html")
		rescue
			@e1.setText(QString::fromUtf8("TTexttReader open error"))					
		end
	end

	def runttrk
		pathset2

		begin
			system("qcop QPE/System 'execute(QString,QString)' TTextReader " + @yhpath2 + "yahoo_news.html")
		rescue
			@e1.setText(QString::fromUtf8("TTexttReader open error"))					
		end
	end


	def offradio1
		@r2.setChecked(false)	
	end

	def offradio2
		@r1.setChecked(false)	
	end

	def onradio1
		@r1.setChecked(true)
		@r2.setChecked(false)	
	end

	def onradio2
		@r1.setChecked(false)
		@r2.setChecked(true)
	end

	def cateset1
		if @c1.isChecked then
			@c1.setChecked(false)
		else
			@c1.setChecked(true)
		end
	end

	def cateset2
		if @c2.isChecked then
			@c2.setChecked(false)
		else
			@c2.setChecked(true)
		end
	end

	def cateset3
		if @c3.isChecked then
			@c3.setChecked(false)
		else
			@c3.setChecked(true)
		end
	end

	def cateset4
		if @c4.isChecked then
			@c4.setChecked(false)
		else
			@c4.setChecked(true)
		end
	end

	def cateset5
		if @c5.isChecked then
			@c5.setChecked(false)
		else
			@c5.setChecked(true)
		end
	end

	def cateset6
		if @c6.isChecked then
			@c6.setChecked(false)
		else
			@c6.setChecked(true)
		end
	end

	def cateset7
		if @c7.isChecked then
			@c7.setChecked(false)
		else
			@c7.setChecked(true)
		end
	end

	def cateset8
		if @c8.isChecked then
			@c8.setChecked(false)
		else
			@c8.setChecked(true)
		end
	end

	def cateset9
		if @c9.isChecked then
			@c9.setChecked(false)
		else
			@c9.setChecked(true)
		end
	end

	def cateset10
		if @c10.isChecked then
			@c10.setChecked(false)
		else
			@c10.setChecked(true)
		end
	end

	def catesetr1
		if @cr1.isChecked then
			@cr1.setChecked(false)
		else
			@cr1.setChecked(true)
		end
	end

	def catesetr2
		if @cr2.isChecked then
			@cr2.setChecked(false)
		else
			@cr2.setChecked(true)
		end
	end

	def catesetr3
		if @cr3.isChecked then
			@cr3.setChecked(false)
		else
			@cr3.setChecked(true)
		end
	end

	def catesetr4
		if @cr4.isChecked then
			@cr4.setChecked(false)
		else
			@cr4.setChecked(true)
		end
	end

	def catesetr5
		if @cr5.isChecked then
			@cr5.setChecked(false)
		else
			@cr5.setChecked(true)
		end
	end

	def catesetr6
		if @cr6.isChecked then
			@cr6.setChecked(false)
		else
			@cr6.setChecked(true)
		end
	end

	def catesetr7
		if @cr7.isChecked then
			@cr7.setChecked(false)
		else
			@cr7.setChecked(true)
		end
	end

	def cateset11
		if @c11.isChecked then
			@c11.setChecked(false)
		else
			@c11.setChecked(true)
		end
	end

	def cateset0
		if @c0.isChecked then
			@c0.setChecked(false)
		else
			@c0.setChecked(true)
		end
	end

	def stopgetyahoo
		if @t != nil then
			@t.kill()

			begin
				if (FileTest.exist?(@categ + ".dat")) then
					yahoodat(@categ)
					#File.delete(@categ + ".dat")
				end
			rescue
			end
			@e1.setText(QString::fromUtf8("取得中止 -> output yahoo_news.html"))
			@Menu.setItemEnabled(@ms,true)
			@Menu.setItemEnabled(@mo,true)
			@Menu.setItemEnabled(@me,false)
			@setting2.setItemEnabled(@md,true)
			@m.setEnabled(true)
			@m4.setEnabled(true)
			@m3.setEnabled(false)
			$netop = ""
			$option = ""

			begin
				if (FileTest.exist?(@categ + ".txt"))
					File.delete(@categ + ".txt")	
				end
				if (FileTest.exist?("weather.txt"))
					File.delete("weather.txt")
				end
			rescue
			end

			GC.start
		end
	end

	def savedirectory
		dlg = SaveDirectoryDialog.new(self)
		res = dlg.exec()
	end

	def getlistwindow
		@e1.setText(QString::fromUtf8("Please Wait"))

		$checker = true
		@okflag3 = false
		@parent.getWidget(Berry::RSS_DESC_VIEW_WIDGET_ID).screenInit()
		@parent.changeScreen(Berry::RSS_DESC_VIEW_WIDGET_ID)

		while $checker
		end

		@categ = "list"

		begin
		count = 0
		totalcount = $urllist.size
			if (totalcount > 0)
				fp2 = File.open("list.dat","w")
				fp2.puts("  ")
				$urllist.each do |line|
					count = count + 1
					@e1.setText(QString::fromUtf8("お好み記事取得中 " + count.to_s + "\/" + totalcount.to_s))
					begin
					timeout(60) {
						open(line) do |f|
							f.each_line() do |linehtml|
								fp2.puts(linehtml)
							end
						end
					}
					rescue
					rescue TimeoutError
					end
				end
				fp2.close
				$urllist = []
				@catename = ["a4aab9a5a4df"].pack("H*")
				yahoodat('list')
			end
		rescue
			@okflag3 = true
		end
	end

	def getsetting
		@Menu.setItemEnabled(@ms,false)
		@Menu.setItemEnabled(@mo,false)
		@Menu.setItemEnabled(@me,true)
		@setting2.setItemEnabled(@md,false)
		@m.setEnabled(false)
		@m4.setEnabled(false)
		@m3.setEnabled(true)

		@okflag = true
		@okflag2 = true
		@newsmaxc = @l1.text.to_str
		@newsmax = @newsmaxc.to_i
		pathset
		save(@yhpathset + "yhttr.xml")


		if ( ($n1m =~ /true/)  != nil ) | ($netop =~ /up/) then
			@e1.setText(QString::fromUtf8("接続確認"))
			if (Ping.pingecho('www.yahoo.co.jp',5,"80")) then
				if ($netop =~ /down/) then
					$netop = "up"
				end
			else
				@e1.setText(QString::fromUtf8("接続待ち"))
				begin
					system("qcop QPE/Network 'connectRequest(QString,QString)'")
				rescue
				end
				sleep 10
				while ( !(Ping.pingecho('www.yahoo.co.jp',5,"80")) ) do
					@e1.setText(QString::fromUtf8("接続中"))
					sleep 1.5
					@e1.setText(QString::fromUtf8("接続中 ."))
					sleep 1.5
					@e1.setText(QString::fromUtf8("接続中 .."))
					sleep 1.5
					@e1.setText(QString::fromUtf8("接続中 ..."))
					sleep 1.5
					@e1.setText(QString::fromUtf8("接続中 ...."))
					sleep 1.5
					@e1.setText(QString::fromUtf8("接続中 ....."))
				end
				@e1.setText(QString::fromUtf8("接続完了"))
			end
		end

		if (!FileTest.exist?(@yhpath))
			Dir.mkdir(@yhpath)
		end
		
		begin
		if @r1.isChecked then
			fp = File.open(@yhpath + "yahoo_news.html","w")
				day = Time.now
				yhdate = $kaisouchr + "Yahoo!news " + day.year.to_s + "-" + day.month.to_s + "-" + day.day.to_s + " " + day.hour.to_s + ":" + day.min.to_s
				fp.puts(yhdate)
			fp.close
			if ($n4m =~ /true/) then
				@e1.setText(QString::fromUtf8("画像削除中"))
				begin
					Dir::open(@yhpath) {|d|
						d.each {|f|
							if ( f =~ /jpg/ ) then
								if (FileTest.exist?(@yhpath + f))
									File.delete(@yhpath + f)
								end
							end
						}
					}
				rescue
				end
			end
		else
			fp = File.open(@yhpath + "yahoo_news.html","a")
				day = Time.now
				yhdate = $kaisouchr + "Yahoo!news " + day.year.to_s + "-" + day.month.to_s + "-" + day.day.to_s + " " + day.hour.to_s + ":" + day.min.to_s
				fp.puts(yhdate)
			fp.close
		end
		rescue
			@e1.setText(QString::fromUtf8("保存先エラー"))
			return					
		end
	end

	def okonomi
	  begin
	   @t = Thread.start do
		Thread.pass

		getsetting
		getlistwindow
		begin
			if @okflag3 then
				@e1.setText(QString::fromUtf8(""))	
			elsif !@okflag then
				@e1.setText(QString::fromUtf8("network error! 取得失敗したカテゴリーがあります。 -> output yahoo_news.html"))
			elsif !@okflag2 then
				@e1.setText(QString::fromUtf8("network error! 取得失敗したカテゴリーがあります。 -> output yahoo_news.html"))
			else
				@e1.setText(QString::fromUtf8("取得完了 -> output yahoo_news.html complete!"))	
			end
		rescue
		end

		@Menu.setItemEnabled(@ms,true)
		@Menu.setItemEnabled(@mo,true)
		@Menu.setItemEnabled(@me,false)
		@setting2.setItemEnabled(@md,true)
		@m.setEnabled(true)
		@m4.setEnabled(true)
		@m3.setEnabled(false)

		begin
			if (($n2m =~ /true/) != nil ) | ($netop =~ /down/) then
				system("qcop QPE/Network 'stop()'")
			end
		rescue
		end
		
		GC.start

		if ( $option =~ /run/ ) then
			close()
		end
	    end
	  rescue
	    return
	  end
	end


	def getyahoo2
	  begin
	   @t = Thread.start do
		Thread.pass

		getsetting
		
		tempurl = ""
		tempcate = ""
		tempcate2= ""
		@okflag	= true
		@okflag2 = true

		fp2 = File.open("list_c.txt","w")
		fp2.close

		dayold = @l0.text.to_str
		if @c1.isChecked then
			@e1.setText(QString::fromUtf8("スポーツ記事一覧取得開始"))
			seturl('spo',dayold)
			getyahoourl2(@cateurl,'spo','off')
		end
		if @c2.isChecked then
			@e1.setText(QString::fromUtf8("経済総合記事一覧取得開始"))
			seturl('bus_all',dayold)
			getyahoourl2(@cateurl,'bus_all','off')
		end
		if @c3.isChecked then
			@e1.setText(QString::fromUtf8("株式記事一覧取得開始"))
			seturl('biz',dayold)
			getyahoourl2(@cateurl,'biz','off')
		end
		if @c4.isChecked then
			@e1.setText(QString::fromUtf8("社会記事一覧取得開始"))
			seturl('soci',dayold)
			getyahoourl2(@cateurl,'soci','off')
		end
		if @c5.isChecked then
			@e1.setText(QString::fromUtf8("政治記事一覧取得開始"))
			seturl('pol',dayold)
			getyahoourl2(@cateurl,'pol','off')
		end
		if @c6.isChecked then
			@e1.setText(QString::fromUtf8("海外記事一覧取得開始"))
			seturl('int',dayold)
			getyahoourl2(@cateurl,'int','off')
		end
		if @c7.isChecked then
			@e1.setText(QString::fromUtf8("市況記事一覧取得開始"))
			seturl('brf',dayold)
			getyahoourl2(@cateurl,'brf','off')
		end
		if @c8.isChecked then
			@e1.setText(QString::fromUtf8("産業記事一覧取得開始"))
			seturl('ind',dayold)
			getyahoourl2(@cateurl,'ind','off')
		end
		if @c9.isChecked then
			@e1.setText(QString::fromUtf8("エンターテーメント記事一覧取得開始"))
			seturl('ent',dayold)
			getyahoourl2(@cateurl,'ent','off')
		end
		if @c10.isChecked then
			@e1.setText(QString::fromUtf8("コンピュータ記事一覧取得開始"))
			seturl('sci',dayold)
			getyahoourl2(@cateurl,'sci','off')
		end
		if @cr1.isChecked then
			@e1.setText(QString::fromUtf8("総合記事(ランキング)一覧取得開始"))
			seturlran('all',dayold)
			@catename = ["c1edb9e728a5e9a5f3a5ada5f3a5b029"].pack("H*")
			getyahoourl2(@cateurl,@catename,'off')
		end
		if @cr2.isChecked then
			@e1.setText(QString::fromUtf8("スポーツ記事(ランキング)一覧取得開始"))
			seturlran('spo',dayold)
			@catename = ["a5b9a5dda1bca5c428a5e9a5f3a5ada5f3a5b029"].pack("H*")
			getyahoourl2(@cateurl,@catename,'off')
		end
		if @cr3.isChecked then
			@e1.setText(QString::fromUtf8("経済総合記事(ランキング)一覧取得開始"))
			seturlran('bus',dayold)
			@catename = ["b7d0bad1c1edb9e728a5e9a5f3a5ada5f3a5b029"].pack("H*")
			getyahoourl2(@cateurl,@catename,'off')
		end
		if @cr4.isChecked then
			@e1.setText(QString::fromUtf8("国内記事(ランキング)一覧取得開始"))
			seturlran('dom',dayold)
			@catename = ["b9f1c6e228a5e9a5f3a5ada5f3a5b029"].pack("H*")
			getyahoourl2(@cateurl,@catename,'off')
		end
		if @cr5.isChecked then
			@e1.setText(QString::fromUtf8("海外記事(ランキング)一覧取得開始"))
			seturlran('int',dayold)
			@catename = ["b3a4b3b028a5e9a5f3a5ada5f3a5b029"].pack("H*")
			getyahoourl2(@cateurl,@catename,'off')
		end
		if @cr6.isChecked then
			@e1.setText(QString::fromUtf8("エンターテーメント記事(ランキング)一覧取得開始"))
			seturlran('ent',dayold)
			@catename = ["a5a8a5f3a5bfa1bca5c6a1bca5e1a5f3a5c828a5e9a5f3a5ada5f3a5b029"].pack("H*")
			getyahoourl2(@cateurl,@catename,'off')
		end
		if @cr7.isChecked then
			@e1.setText(QString::fromUtf8("コンピュータ記事(ランキング)一覧取得開始"))
			seturlran('sci',dayold)
			@catename = ["a5b3a5f3a5d4a5e5a1bca5bf28a5e9a5f3a5ada5f3a5b029"].pack("H*")
			getyahoourl2(@cateurl,@catename,'off')
		end

		#getlistwindow

		if @c11.isChecked then
			@e2.text.to_str.each do |line|
				if ( line =~ /^\#/ ) != nil then
				else
					if ( line =~ /^\/fc/ ) != nil then
						tempurl = "http://dailynews.yahoo.co.jp" + line
						tempcate = line
						tempcate2 = tempcate.split('/')
						@kobetu = tempcate2[3]
						@e1.setText(QString::fromUtf8("個別設定記事(" + @kobetu + ")一覧取得開始"))
						getyahoourl2(tempurl,@kobetu,'on')
					end
					if ( line =~ /^\/cate/ ) != nil then
						tempcate = line
						tempcate2 = tempcate.split('/')
						@kobetu = tempcate2[2]
						@e1.setText(QString::fromUtf8("その他カテゴリ記事(" + @kobetu + ")一覧取得開始"))
						seturl(@kobetu,dayold)
						getyahoourl2(@cateurl,@kobetu,'off')
					end
				end
			end
		end
		getlistwindow
		if @c11.isChecked then
			@e2.text.to_str.each do |line|
				if ( line =~ /^\#/ ) != nil then
				else
					if ( line =~ /^\/weather/ ) != nil then
						lineurl = line.split(',')
						@tempurl = "http://weather.yahoo.co.jp" + lineurl[0]
						getweather(@tempurl)
						tempcate = lineurl[0]
						tempcate2 = tempcate.split('/')
						if lineurl[1] != nil then
							if lineurl[1] =~ /off/ then
							else
								if lineurl[1].to_i <= 6 then
									@tempurl = "http://weather.yahoo.co.jp/weather/raincloud/" + tempcate2[3] + "/index.html" + "?c=" + lineurl[1]
								else
									@tempurl = "http://weather.yahoo.co.jp/weather/raincloud/" + tempcate2[3] + "/index.html" + "?c=6"
								end
								getweather2(@tempurl)
							end
						else
							@tempurl = "http://weather.yahoo.co.jp/weather/raincloud/" + tempcate2[3] + "/index.html"
							getweather2(@tempurl)
						end
					end
				end
			end
		end
		if (@okflag3 && !@c11.isChecked) then
			@e1.setText(QString::fromUtf8(""))	
		elsif !@okflag then
			@e1.setText(QString::fromUtf8("network error! 取得失敗したカテゴリーがあります。 -> output yahoo_news.html"))
		elsif !@okflag2 then
			@e1.setText(QString::fromUtf8("network error! 取得失敗したカテゴリーがあります。 -> output yahoo_news.html"))
		else
			@e1.setText(QString::fromUtf8("取得完了 -> output yahoo_news.html complete!"))	
		end

		@Menu.setItemEnabled(@ms,true)
		@Menu.setItemEnabled(@mo,true)
		@Menu.setItemEnabled(@me,false)
		@setting2.setItemEnabled(@md,true)
		@m.setEnabled(true)
		@m4.setEnabled(true)
		@m3.setEnabled(false)

		begin
			if (($n2m =~ /true/) != nil ) | ($netop =~ /down/) then
				system("qcop QPE/Network 'stop()'")
			end
		rescue
		end
		
		GC.start

		if ( $option =~ /run/ ) then
			close()
		end
	    end
	  rescue
	    return
	  end
	end

	def getyahoo
	  begin
	   @t = Thread.start do
		Thread.pass

		getsetting
		
		tempurl = ""
		tempcate = ""
		tempcate2= ""

		dayold = @l0.text.to_str
		if @c1.isChecked then
			@e1.setText(QString::fromUtf8("スポーツ記事一覧取得開始"))
			seturl('spo',dayold)
			getyahoourl(@cateurl,'spo','off')
			yahoodat('spo')
		end
		if @c2.isChecked then
			@e1.setText(QString::fromUtf8("経済総合記事一覧取得開始"))
			seturl('bus_all',dayold)
			getyahoourl(@cateurl,'bus_all','off')
			yahoodat('bus_all')
		end
		if @c3.isChecked then
			@e1.setText(QString::fromUtf8("株式記事一覧取得開始"))
			seturl('biz',dayold)
			getyahoourl(@cateurl,'biz','off')
			yahoodat('biz')
		end
		if @c4.isChecked then
			@e1.setText(QString::fromUtf8("社会記事一覧取得開始"))
			seturl('soci',dayold)
			getyahoourl(@cateurl,'soci','off')
			yahoodat('soci')
		end
		if @c5.isChecked then
			@e1.setText(QString::fromUtf8("政治記事一覧取得開始"))
			seturl('pol',dayold)
			getyahoourl(@cateurl,'pol','off')
			yahoodat('pol')
		end
		if @c6.isChecked then
			@e1.setText(QString::fromUtf8("海外記事一覧取得開始"))
			seturl('int',dayold)
			getyahoourl(@cateurl,'int','off')
			yahoodat('int')
		end
		if @c7.isChecked then
			@e1.setText(QString::fromUtf8("市況記事一覧取得開始"))
			seturl('brf',dayold)
			getyahoourl(@cateurl,'brf','off')
			yahoodat('brf')
		end
		if @c8.isChecked then
			@e1.setText(QString::fromUtf8("産業記事一覧取得開始"))
			seturl('ind',dayold)
			getyahoourl(@cateurl,'ind','off')
			yahoodat('ind')
		end
		if @c9.isChecked then
			@e1.setText(QString::fromUtf8("エンターテーメント記事一覧取得開始"))
			seturl('ent',dayold)
			getyahoourl(@cateurl,'ent','off')
			yahoodat('ent')
		end
		if @c10.isChecked then
			@e1.setText(QString::fromUtf8("コンピュータ記事一覧取得開始"))
			seturl('sci',dayold)
			getyahoourl(@cateurl,'sci','off')
			yahoodat('sci')
		end
		if @cr1.isChecked then
			@e1.setText(QString::fromUtf8("総合記事(ランキング)一覧取得開始"))
			seturlran('all',dayold)
			getyahoourl(@cateurl,'rall','off')
			@catename = ["c1edb9e728a5e9a5f3a5ada5f3a5b029"].pack("H*")
			yahoodat('rall')
		end
		if @cr2.isChecked then
			@e1.setText(QString::fromUtf8("スポーツ記事(ランキング)一覧取得開始"))
			seturlran('spo',dayold)
			getyahoourl(@cateurl,'rspo','off')
			@catename = ["a5b9a5dda1bca5c428a5e9a5f3a5ada5f3a5b029"].pack("H*")
			yahoodat('rspo')
		end
		if @cr3.isChecked then
			@e1.setText(QString::fromUtf8("経済総合記事(ランキング)一覧取得開始"))
			seturlran('bus',dayold)
			getyahoourl(@cateurl,'rbus','off')
			@catename = ["b7d0bad1c1edb9e728a5e9a5f3a5ada5f3a5b029"].pack("H*")
			yahoodat('rbus')
		end
		if @cr4.isChecked then
			@e1.setText(QString::fromUtf8("国内記事(ランキング)一覧取得開始"))
			seturlran('dom',dayold)
			getyahoourl(@cateurl,'rdom','off')
			@catename = ["b9f1c6e228a5e9a5f3a5ada5f3a5b029"].pack("H*")
			yahoodat('rdom')
		end
		if @cr5.isChecked then
			@e1.setText(QString::fromUtf8("海外記事(ランキング)一覧取得開始"))
			seturlran('int',dayold)
			getyahoourl(@cateurl,'rint','off')
			@catename = ["b3a4b3b028a5e9a5f3a5ada5f3a5b029"].pack("H*")
			yahoodat('rint')
		end
		if @cr6.isChecked then
			@e1.setText(QString::fromUtf8("エンターテーメント記事(ランキング)一覧取得開始"))
			seturlran('ent',dayold)
			getyahoourl(@cateurl,'rent','off')
			@catename = ["a5a8a5f3a5bfa1bca5c6a1bca5e1a5f3a5c828a5e9a5f3a5ada5f3a5b029"].pack("H*")
			yahoodat('rent')
		end
		if @cr7.isChecked then
			@e1.setText(QString::fromUtf8("コンピュータ記事(ランキング)一覧取得開始"))
			seturlran('sci',dayold)
			getyahoourl(@cateurl,'rsci','off')
			@catename = ["a5b3a5f3a5d4a5e5a1bca5bf28a5e9a5f3a5ada5f3a5b029"].pack("H*")
			yahoodat('rsci')
		end
		if @c11.isChecked then
			@e2.text.to_str.each do |line|
				if ( line =~ /^\#/ ) != nil then
				else
					if ( line =~ /^\/fc/ ) != nil then
						tempurl = "http://dailynews.yahoo.co.jp" + line
						tempcate = line
						tempcate2 = tempcate.split('/')
						@kobetu = tempcate2[3]
						@e1.setText(QString::fromUtf8("個別設定記事(" + @kobetu + ")一覧取得開始"))
						getyahoourl(tempurl,@kobetu,'on')
						yahoodat(@kobetu)
					end
					if ( line =~ /^\/weather/ ) != nil then
						lineurl = line.split(',')
						@tempurl = "http://weather.yahoo.co.jp" + lineurl[0]
						getweather(@tempurl)
						tempcate = lineurl[0]
						tempcate2 = tempcate.split('/')
						if lineurl[1] != nil then
							if lineurl[1] =~ /off/ then
							else
								if lineurl[1].to_i <= 6 then
									@tempurl = "http://weather.yahoo.co.jp/weather/raincloud/" + tempcate2[3] + "/index.html" + "?c=" + lineurl[1]
								else
									@tempurl = "http://weather.yahoo.co.jp/weather/raincloud/" + tempcate2[3] + "/index.html" + "?c=6"
								end
								getweather2(@tempurl)
							end
						else
							@tempurl = "http://weather.yahoo.co.jp/weather/raincloud/" + tempcate2[3] + "/index.html"
							getweather2(@tempurl)
						end
					end
					if ( line =~ /^\/cate/ ) != nil then
						tempcate = line
						tempcate2 = tempcate.split('/')
						@kobetu = tempcate2[2]
						@e1.setText(QString::fromUtf8("その他カテゴリ記事(" + @kobetu + ")一覧取得開始"))
						seturl(@kobetu,dayold)
						getyahoourl(@cateurl,@kobetu,'off')
						yahoodat(@kobetu)
					end
				end
			end
		end

		if !@okflag then
			@e1.setText(QString::fromUtf8("network error! 取得失敗したカテゴリーがあります。 -> output yahoo_news.html"))
		elsif !@okflag2 then
			@e1.setText(QString::fromUtf8("network error! 取得失敗したカテゴリーがあります。 -> output yahoo_news.html"))
		else
			@e1.setText(QString::fromUtf8("取得完了 -> output yahoo_news.html complete!"))	
		end
		@Menu.setItemEnabled(@ms,true)
		@Menu.setItemEnabled(@mo,true)
		@Menu.setItemEnabled(@me,false)
		@setting2.setItemEnabled(@md,true)
		@m.setEnabled(true)
		@m4.setEnabled(true)
		@m3.setEnabled(false)

		begin
			if (($n2m =~ /true/) != nil ) | ($netop =~ /down/) then
				system("qcop QPE/Network 'stop()'")
			end
		rescue
		end
		
		GC.start

		if ( $option =~ /run/ ) then
			close()
		end
	    end
	  rescue
	    return
	  end
	end

	def seturl(setcate,setday)
		if @c0.isChecked then
			@cateurl = "http://headlines.yahoo.co.jp/hl?c=" + setcate + "&t=l&d=" + setday
		else
			@cateurl = "http://headlines.yahoo.co.jp/hl?c=" + setcate + "&t=l"
		end
	end

	def seturlran(setcate,setday)
			@cateurl = "http://headlines.yahoo.co.jp/accr?ty=t&c=" + setcate
	end


	def getyahoourl2(yahoourl, cate, yhoption)

		@newsmaxc = @l1.text.to_str
		@newsmax = @newsmaxc.to_i

		@categ = "list"
		begin
		fp1 = File.open("list_c.txt","a")
			fp1.puts("option yahoonewsTTR " + yhoption)
			fp1.puts("yahoonewsTTR " + cate)
			begin
				timeout(60) {
					open(yahoourl) do |f|
						f.each_line() do |line|
							fp1.puts(line)
						end
					end
				}
			rescue TimeoutError
			end
			if ( yhoption =~ /off/ ) != nil then
				if ( cate =~ /^r/ ) != nil then
					if ( @newsmax > 20 ) then
						@newsmax = 20
					end
				end
				if ( @newsmax > 25 )  then
					begin
						timeout(60) {
							open(yahoourl + "&p=1") do |f|
								f.each_line() do |line|
									fp1.puts(line)
								end
							end
						}
					rescue TimeoutError
					end
				end
				if ( @newsmax > 50 )  then
					begin
						timeout(60) {
							open(yahoourl + "&p=2") do |f|
								f.each_line() do |line|
									fp1.puts(line)
								end
							end
						}
					rescue TimeoutError
					end
				end
				if ( @newsmax > 75 )  then
					begin
						timeout(60) {
							open(yahoourl + "&p=3") do |f|
								f.each_line() do |line|
									fp1.puts(line)
								end
							end
						}
					rescue TimeoutError
					end
				end
			end
			if ( yhoption =~ /on/ ) != nil then
				if ( @newsmax > 25 ) then
					@newsmax = 25
				end
			end
			#@okflag = true
		fp1.close
		rescue
			@okflag = false
			return
		end
		show()

	end

	def getyahoourl(yahoourl, cate, yhoption)

		@newsmaxc = @l1.text.to_str
		@newsmax = @newsmaxc.to_i

		@categ = cate
		begin
		fp1 = File.open(cate + ".txt","w")
			begin
				timeout(60) {
					open(yahoourl) do |f|
						f.each_line() do |line|
							fp1.puts(line)
						end
					end
				}
			rescue TimeoutError
			end
			if ( yhoption =~ /off/ ) != nil then
				if ( cate =~ /^r/ ) != nil then
					if ( @newsmax > 20 ) then
						@newsmax = 20
					end
				end
				if ( @newsmax > 25 )  then
					begin
						timeout(60) {
							open(yahoourl + "&p=1") do |f|
								f.each_line() do |line|
									fp1.puts(line)
								end
							end
						}
					rescue TimeoutError
					end
				end
				if ( @newsmax > 50 )  then
					begin
						timeout(60) {
							open(yahoourl + "&p=2") do |f|
								f.each_line() do |line|
									fp1.puts(line)
								end
							end
						}
					rescue TimeoutError
					end
				end
				if ( @newsmax > 75 )  then
					begin
						timeout(60) {
							open(yahoourl + "&p=3") do |f|
								f.each_line() do |line|
									fp1.puts(line)
								end
							end
						}
					rescue TimeoutError
					end
				end
			end
			if ( yhoption =~ /on/ ) != nil then
				if ( @newsmax > 25 ) then
					@newsmax = 25
				end
			end
			#@okflag = true
		fp1.close
		rescue
			@okflag = false
			return
		end
		show()

		templine = []
		yhurl = ""
		buf = ""
		ulMode = false
		status = ""
		titleMode = false
		@catename = ""
		catemp = ""

		fp1 = File.open(cate + ".txt","r")
		fp1.each do |line|
			if (line =~ /<title>/) != nil then
				if (line =~ /<\/head>/) then
					catemp = line.sub(/<title>Yahoo.*-  /,"")
					@catename = catemp.sub(/<\/title><\/head>/,"")
				end
				titleMode = true
			end
			if (line =~ /<\/title>/) != nil then
				titleMode = false
			end
			if titleMode then
				if (line =~ /<title>/) then
				else
					@catename = line
				end
			end
			if ( yhoption =~ /off/ ) != nil then
				if (line =~ /<ul>/) != nil then
					ulMode = true
				end
				if (line =~ /News_ranking_TABLE/) != nil then
					ulMode = true
				end
				if ulMode then
					temp = line .split('"')
					for i in 1..17
						templine.push temp[i]
					end
				end
				if (line =~ /<\/ul>/) != nil then
					ulMode = false
				end
				if (line =~ /\/News_ranking_TABLE/) != nil then
					ulMode = false
				end
			else
				if (line =~ /OUTLINE/) != nil then
					ulMode = true
				end
				if (line =~ /news_stories/) != nil then
					ulMode = false
				end
				if ulMode then
					temp = line .split('"')
					templine.push temp[3]
				end

			end
		end
		fp1.close
		fp1 = ""

		count = 0
		fp2 = File.open(cate + ".dat","w")
		fp2.puts("  ")
		templine.each do |line|
			if (line != nil ) && ( count < @newsmax )  then
				if (line =~ /http|yahoo/) != nil then
					if (line =~ /photo/) != nil then
					else
						count += 1

						if (cate =~ /^spo/) then
							@e1.setText(QString::fromUtf8("スポーツ記事取得中 " + count.to_s + "\/" + @newsmax.to_s))
						elsif (cate =~ /^bus_all/) then
							@e1.setText(QString::fromUtf8("経済総合記事取得中 " + count.to_s + "\/" + @newsmax.to_s))
						elsif (cate =~ /^biz/) then
							@e1.setText(QString::fromUtf8("株式記事取得中 " + count.to_s + "\/" + @newsmax.to_s))
						elsif (cate =~ /^soci/) then
							@e1.setText(QString::fromUtf8("社会記事取得中 " + count.to_s + "\/" + @newsmax.to_s))
						elsif (cate =~ /^pol/) then
							@e1.setText(QString::fromUtf8("政治記事取得中 " + count.to_s + "\/" + @newsmax.to_s))
						elsif (cate =~ /^int/) then
							@e1.setText(QString::fromUtf8("海外記事取得中 " + count.to_s + "\/" + @newsmax.to_s))
						elsif (cate =~ /^brf/) then
							@e1.setText(QString::fromUtf8("市況記事取得中 " + count.to_s + "\/" + @newsmax.to_s))
						elsif (cate =~ /^ind/) then
							@e1.setText(QString::fromUtf8("産業記事取得中 " + count.to_s + "\/" + @newsmax.to_s))
						elsif (cate =~ /^ent/) then
							@e1.setText(QString::fromUtf8("エンターテーメント記事取得中 " + count.to_s + "\/" + @newsmax.to_s))
						elsif (cate =~ /^sci/) then
							@e1.setText(QString::fromUtf8("コンピュータ記事取得中 " + count.to_s + "\/" + @newsmax.to_s))
						elsif (cate =~ /^rall/) then
							@e1.setText(QString::fromUtf8("総合記事(ランキング)取得中 " + count.to_s + "\/" + @newsmax.to_s))
						elsif (cate =~ /^rdom/) then
							@e1.setText(QString::fromUtf8("国内記事(ランキング)取得中 " + count.to_s + "\/" + @newsmax.to_s))
						elsif (cate =~ /^rbus/) then
							@e1.setText(QString::fromUtf8("経済記事(ランキング)取得中 " + count.to_s + "\/" + @newsmax.to_s))
						elsif (cate =~ /rspo/) then
							@e1.setText(QString::fromUtf8("スポーツ記事(ランキング)取得中 " + count.to_s + "\/" + @newsmax.to_s))
						elsif (cate =~ /^rint/) then
							@e1.setText(QString::fromUtf8("海外記事(ランキング)取得中 " + count.to_s + "\/" + @newsmax.to_s))
						elsif (cate =~ /^rent/) then
							@e1.setText(QString::fromUtf8("エンターテーメント記事(ランキング)取得中 " + count.to_s + "\/" + @newsmax.to_s))
						elsif (cate =~ /^rsci/) then
							@e1.setText(QString::fromUtf8("コンピュータ記事(ランキング)取得中 " + count.to_s + "\/" + @newsmax.to_s))
						else
							@e1.setText(QString::fromUtf8("個別設定記事(" + @kobetu + ")取得中 " + count.to_s + "\/" + @newsmax.to_s))
						end
						begin
							timeout(60) {
								open(line) do |f|
									f.each_line() do |linehtml|
										fp2.puts(linehtml)
									end
								end
							}
						rescue
							#@okflag = false
							#return
						rescue TimeoutError
						end
					end
				end
			end
		end
		templine = ""
		fp2.close
	end

	def yahoodat(cate)
		templine = []
		tempnews = []
		imgline = []
		fp = []
		filename = []
		yhurl = ""
		buf = ""
		titleMode = false
		newsMode = false
		news2Mode = false
		photoMode = false
		sedline = ""
		sedline2 = ""

			begin
				fp = File.open(cate + ".dat","r")
			rescue

				if (FileTest.exist?(@categ + ".txt"))
					File.delete(@categ + ".txt")	
				end
				@okflag = false
				return
			end
			templine.push $kaisouchr * 2 + "Yahoo!news " + @catename
			fp.each_line() do |line|
				if (line =~ /<title>/) != nil then
					titleMode = true
				end
				if (line =~ /<\/title>/) != nil then
					titleMode = false
				end
				if titleMode then
					if (line =~ /<title>/) then
					else
						templine.push $kaisouchr *3 + line
					end
				end
				if (line =~ /\/CONTENTS_TITLE_TABLE/) != nil then
					newsMode = true
				end
				if (((line =~ /^<center>/) != nil)|((line =~ /^<\/td><\/tr>/) != nil)) then
					newsMode = false
					news2Mode = false
				end
				if newsMode then
					if (line =~ /<b>/) != nil then
						if (line =~ /<\/font>/) != nil then						
							news2Mode = true
						end
					end
				end
				if news2Mode then
					if (line =~ /\/NEXT_NAVI_TABLE/) != nil then
						photoMode = true
					end
				end
				if (line =~ /^<table cellpadding=3 cellspacing=0 border=0 width=500>/) != nil then
					photoMode = true
				end
				if (line =~ /^<p><center>|^<\/td><\/tr>/) != nil then
					photoMode = false
				end				
				if ( news2Mode | photoMode ) then
						#templine.push line
						if (line =~ /images/) != nil then
							temp = line .split('"')
							if (temp[9] =~ /jpg/) != nil then
								if temp[9] == nil then
								else
									@e1.setText(QString::fromUtf8("画像取得開始")) 
									begin
										system("wget -P " + @yhpath + " -nv -nc -T 4 -t 1 " + temp[9] + "")
									rescue
									end
 									@e1.setText(QString::fromUtf8("画像取得完了"))

								end
							end
							if (temp[11] =~ /jpg/) != nil then
								if temp[11] == nil then
								else
									@e1.setText(QString::fromUtf8("画像取得開始")) 
									begin
										system("wget -P " + @yhpath + " -nv -nc -T 4 -t 1 " + temp[11] + "")
									rescue
									end
									@e1.setText(QString::fromUtf8("画像取得完了")) 
								end
							end
							if (temp[5] =~ /jpg/) != nil then
								if temp[5] == nil then
								else
									@e1.setText(QString::fromUtf8("画像取得開始"))
									begin 
										system("wget -P " + @yhpath + " -nv -nc -T 4 -t 1 " + temp[5] + "")
									rescue
									end
									@e1.setText(QString::fromUtf8("画像取得完了")) 
								end
							end
							if (temp[7] =~ /jpg/) != nil then
								if temp[7] == nil then
								else
									@e1.setText(QString::fromUtf8("画像取得開始"))
									begin 
										system("wget -P " + @yhpath + " -nv -nc -T 4 -t 1 " + temp[7] + "")
									rescue
									end
									@e1.setText(QString::fromUtf8("画像取得完了")) 
								end
							end
							sedline  = line.sub(/http:\/\/ca.c.yimg.*images\/........\/[a-z]*\//,".\/")  
							sedline2 = sedline.sub(/http:\/\/ca.c.yimg.*images\/........\/[a-z]*_[a-z]*\//,".\/")
							templine.push sedline2.sub(/\.jpg /,"\.jpg")
						else
							templine.push line
						end
				end
			end
			fp.close
			
			fp = File.open( @yhpath + "yahoo_news.html","a")
			templine.each do |line|
				fp.puts(line)
			end
			fp.close

			begin
				if (FileTest.exist?(@categ + ".dat"))
					File.delete(@categ + ".dat")	
				end
				if (FileTest.exist?(@categ + ".txt"))
					File.delete(@categ + ".txt")	
				end
			rescue
			end

		filename = ""
		templine = ""
		tempnews = ""
		imgline = ""
		buf = ""
		fp = ""
		GC.start
	end

	def getweather(weatherurl)
		@categ = "weather"

		pathset

		templine = []
		line = ""
		linesed = ""
		titleMode = false
		weatherMode = false
		weather2Mode = false
		@e1.setText(QString::fromUtf8("天気情報取得開始"))
		begin
		fp1 = File.open("weather.txt","w")
			begin
				timeout(60) {
					open(weatherurl) do |f|
						f.each_line() do |line|
							fp1.puts(line)
						end
					end
				}
			rescue TimeoutError
			end
			#@okflag2 = true
		fp1.close
		rescue
			@okflag2 = false
			return
		end

		fp1 = File.open("weather.txt","r")
		fp1.each do |line|
				if (line =~ /<title>/) != nil then
					titleMode = true
				end
				if titleMode then
					linesed = line.sub(/<title>/,"")
					templine.push $kaisouchr *2 + linesed.sub(/<\/title>/,"")
				end
				if (line =~ /<\/title>/) != nil then
					titleMode = false
				end
				if (line =~ /\/LEFT_COLUMN/) != nil then
					weatherMode = true
				end
				if weatherMode then
					if (line =~ /490/) != nil then
						weather2Mode = true
					end
				end
				if weather2Mode then
					if (line =~ /clear.gif/) != nil then
					else
						#templine.push line
						if (line =~ /images/) != nil then
							temp = line .split('"')
							if (temp[1] =~ /gif/) != nil then
								if temp[1] == nil then
								else
									@e1.setText(QString::fromUtf8("天気アイコン取得開始"))
									begin
										system("wget -P " + @yhpath + " -nv -nc -T 4 -t 1 " + temp[1] + "")
									rescue
									end
									@e1.setText(QString::fromUtf8("天気アイコン画像取得開始"))
								end
							end
							sedline  = line.sub(/http:\/\/ca.c.yimg.*forcast\//,".\/")
							sedline2  = sedline.sub(/pinpoint\//,"")
							templine.push sedline2.sub(/\.gif /,"\.gif")
						else
							templine.push line
						end
					end
				end
				if (((line =~ /Local_Link/) != nil) | ((line =~ /^<\!--- NOTES --->/) != nil) | ((line =~ /\/MAIN_CONTENTS_table/) != nil)) then
					templine.push "<br>"
					weatherMode = false
					weather2Mode = false
				end
		end
		fp1.close

		fp = File.open( @yhpath + "yahoo_news.html","a")
		templine.each do |line|
			fp.puts(line)
		end
		fp.close

		File.delete("weather.txt")

		templine = ""
		line = ""
		linesed = ""

		fp = ""
		GC.start
	end

	def getweather2(weatherurl)
		@categ = "weather"

		pathset

		templine = []
		line = ""
		linesed = ""
		weatherMode = false
		weather2Mode = false
		@e1.setText(QString::fromUtf8("天気雨雲情報取得開始"))
		begin
		fp1 = File.open("weather.txt","w")
			begin
				timeout(60) {
					open(weatherurl) do |f|
						f.each_line() do |line|
							fp1.puts(line)
						end
					end
				}
			rescue TimeoutError
			end
			#@okflag = true
		fp1.close
		rescue
			@okflag2 = false
			return
		end

		fp1 = File.open("weather.txt","r")
		fp1.each do |line|
				if (line =~ /\/LEFT_COLUMN/) != nil then
					weatherMode = true
				end
				if weatherMode then
					if (line =~ /490/) != nil then
						weather2Mode = true
					end
				end
				if weather2Mode then
					if (line =~ /clear.gif/) != nil then
							temp = line .split('"')
							if (temp[3] =~ /gif/) != nil then
								if temp[3] == nil then
								else
									@e1.setText(QString::fromUtf8("雨雲画像取得開始"))
									begin
										system("wget -P " + @yhpath + " -nv -nc -T 4 -t 1 " + temp[3] + "")
									rescue
									end
									@e1.setText(QString::fromUtf8("雨雲画像取得完了")) 
								end
							end
							sedline  = line.sub(/http:\/\/ca.c.yimg.*images\//,".\/")
							templine.push sedline.sub(/\.gif /,"\.gif")
					else
						if (line =~ /raincloud/) != nil then
							temp = line .split('"')
							if (temp[1] =~ /jpg/) != nil then
								if temp[1] == nil then
								else
									@e1.setText(QString::fromUtf8("雨雲画像取得開始"))
									begin
										tempweather = temp[1].sub(/http:\/\/ca.c.yimg.*raincloud\/img\//,"")
										if (FileTest.exist?(@yhpath + tempweather))
											File.delete(@yhpath + tempweather)	
										end
										system("wget -P " + @yhpath + " -nv -T 4 -t 1 " + temp[1] + "")
									rescue
									end
									@e1.setText(QString::fromUtf8("雨雲画像取得完了")) 
								end
							end
							sedline  = line.sub(/http:\/\/ca.c.yimg.*raincloud\/img\//,".\/")
							templine.push sedline.sub(/\.jpg /,"\.jpg")
						else
							templine.push line
						end
					end
				end
				if (line =~ /\/CONTENTS_table/) != nil then
					weatherMode = false
					weather2Mode = false
				end
		end
		fp1.close

		fp = File.open( @yhpath + "yahoo_news.html","a")
		templine.each do |line|
			fp.puts(line)
		end
		fp.close

		templine = ""
		line = ""
		linesed = ""
		fp = ""

		File.delete("weather.txt")

		GC.start
	end

	def load(filePath)
		if (!FileTest.exist?(filePath))
			return
		end
		fp = File.open(filePath, "r")
		doc = REXML::Document.new(fp)

		element = doc.elements["config/yhno"]
		if (!element.nil?)
			@l1.setText(element.attributes["yhnum"])
		end


		element = doc.elements["config/memory"]
		if (!element.nil?)
			if(element.attributes["saveover"] =~ /true/) then
				onradio2
			else
				onradio1
			end
		end

		element = doc.elements["config/memory2"]
		if (!element.nil?)
			@m1.setCurrentItem(element.attributes["save"].to_i)
		end

		element = doc.elements["config/kobetu1_url"]
		if (!element.nil?)
			@e2.setText(element.attributes["path"])
		end

		element = doc.elements["config/ch1"]
		if (!element.nil?)
			if(element.attributes["yhget"] =~ /true/) then
				@c1.setChecked(true)
			end
		end

		element = doc.elements["config/ch2"]
		if (!element.nil?)
			if(element.attributes["yhget"] =~ /true/) then
				@c2.setChecked(true)
			end
		end

		element = doc.elements["config/ch3"]
		if (!element.nil?)
			if(element.attributes["yhget"] =~ /true/) then
				@c3.setChecked(true)
			end
		end

		element = doc.elements["config/ch4"]
		if (!element.nil?)
			if(element.attributes["yhget"] =~ /true/) then
				@c4.setChecked(true)
			end
		end

		element = doc.elements["config/ch5"]
		if (!element.nil?)
			if(element.attributes["yhget"] =~ /true/) then
				@c5.setChecked(true)
			end
		end

		element = doc.elements["config/ch6"]
		if (!element.nil?)
			if(element.attributes["yhget"] =~ /true/) then
				@c6.setChecked(true)
			end
		end

		element = doc.elements["config/ch7"]
		if (!element.nil?)
			if(element.attributes["yhget"] =~ /true/) then
				@c7.setChecked(true)
			end
		end

		element = doc.elements["config/ch8"]
		if (!element.nil?)
			if(element.attributes["yhget"] =~ /true/) then
				@c8.setChecked(true)
			end
		end

		element = doc.elements["config/ch9"]
		if (!element.nil?)
			if(element.attributes["yhget"] =~ /true/) then
				@c9.setChecked(true)
			end
		end

		element = doc.elements["config/ch10"]
		if (!element.nil?)
			if(element.attributes["yhget"] =~ /true/) then
				@c10.setChecked(true)
			end
		end

		begin
		element = doc.elements["config/chr1"]
		if (!element.nil?)
			if(element.attributes["yhget"] =~ /true/) then
				@cr1.setChecked(true)
			end
		end

		element = doc.elements["config/chr2"]
		if (!element.nil?)
			if(element.attributes["yhget"] =~ /true/) then
				@cr2.setChecked(true)
			end
		end

		element = doc.elements["config/chr3"]
		if (!element.nil?)
			if(element.attributes["yhget"] =~ /true/) then
				@cr3.setChecked(true)
			end
		end

		element = doc.elements["config/chr4"]
		if (!element.nil?)
			if(element.attributes["yhget"] =~ /true/) then
				@cr4.setChecked(true)
			end
		end

		element = doc.elements["config/chr5"]
		if (!element.nil?)
			if(element.attributes["yhget"] =~ /true/) then
				@cr5.setChecked(true)
			end
		end

		element = doc.elements["config/chr6"]
		if (!element.nil?)
			if(element.attributes["yhget"] =~ /true/) then
				@cr6.setChecked(true)
			end
		end

		element = doc.elements["config/chr7"]
		if (!element.nil?)
			if(element.attributes["yhget"] =~ /true/) then
				@cr7.setChecked(true)
			end
		end
		rescue
		end

		element = doc.elements["config/ch11"]
		if (!element.nil?)
			if(element.attributes["yhget"] =~ /true/) then
				@c11.setChecked(true)
			end
		end

		element = doc.elements["config/paths"]
		if (!element.nil?)
			$yhpaths = element.attributes["ps"]
		else
			$yhpaths = "/home/samba/SD_Card/Documents/Image_Files/"
		end

		element = doc.elements["config/pathm"]
		if (!element.nil?)
			$yhpathm = element.attributes["pm"]
		else
			$yhpathm = "/home/zaurus/Documents/Image_Files/"
		end

		element = doc.elements["config/pathc"]
		if (!element.nil?)
			$yhpathc = element.attributes["pc"]
		else
			$yhpathc = "/home/samba/CF_Card/Documents/Image_Files/"
		end

		element = doc.elements["config/kaisou"]
		if (!element.nil?)
			$kaisouchr = element.attributes["chr"]
		else
			$kaisouchr = "."
		end

		element = doc.elements["config/ng"]
		if (!element.nil?)
			if(element.attributes["start"] =~ /true/) then
				$n1m = "true"
			else
				$n1m = "false"
			end
		else
			$n1m = "false"
		end

		element = doc.elements["config/ns"]
		if (!element.nil?)
			if(element.attributes["end"] =~ /true/) then
				$n2m = "true"
			else
				$n2m = "false"
			end
		else
			$n2m = "false"
		end

		element = doc.elements["config/ds"]
		if (!element.nil?)
			if(element.attributes["end"] =~ /true/) then
				$n3m = "true"
			else
				$n3m = "false"
			end
		else
			$n3m = "false"
		end

		element = doc.elements["config/di"]
		if (!element.nil?)
			if(element.attributes["end"] =~ /true/) then
				$n4m = "true"
			else
				$n4m = "false"
			end
		else
			$n4m = "false"
		end

		element = doc.elements["config/sdir"]
		if (!element.nil?)
			@sdate = element.attributes["path"]
		else
			@sdate = @date
		end

		fp.close()
	end

	def save(filePath)

		@ch1 = @c1.isChecked.to_s
		@ch2 = @c2.isChecked.to_s
		@ch3 = @c3.isChecked.to_s
		@ch4 = @c4.isChecked.to_s
		@ch5 = @c5.isChecked.to_s
		@ch6 = @c6.isChecked.to_s
		@ch7 = @c7.isChecked.to_s
		@ch8 = @c8.isChecked.to_s
		@ch9 = @c9.isChecked.to_s
		@ch10 = @c10.isChecked.to_s
		@chr1 = @cr1.isChecked.to_s
		@chr2 = @cr2.isChecked.to_s
		@chr3 = @cr3.isChecked.to_s
		@chr4 = @cr4.isChecked.to_s
		@chr5 = @cr5.isChecked.to_s
		@chr6 = @cr6.isChecked.to_s
		@chr7 = @cr7.isChecked.to_s
		@ch11 = @c11.isChecked.to_s
		@me0 = @r2.isChecked.to_s
		@me1 = @m1.currentItem.to_s
		@kobetu1_url = @e2.text.to_str

		@ng1 = $n1m
		@ng2 = $n2m
		@ds1 = $n3m
		@di1 = $n4m

		fp = File.new(filePath, "w")
		fp.puts("<?xml version='1.0' encoding='UTF-8' ?>")
		fp.puts("<config>")

		str = "\t<yhno yhnum=\""
		if (!@newsmaxc.nil?)
			str += @newsmaxc
		end
		str += "\" />"
		fp.puts(str)

		str = "\t<memory saveover=\""
		if (!@me0.nil?)
			str += @me0
		end
		str += "\" />"
		fp.puts(str)

		str = "\t<memory2 save=\""
		if (!@me1.nil?)
			str += @me1
		end
		str += "\" />"
		fp.puts(str)

		str = "\t<kobetu1_url path=\""
		if (!@kobetu1_url.nil?)
			str += @kobetu1_url
		end
		str += "\" />"
		fp.puts(str)

		str = "\t<ch1 yhget=\""
		if (!@ch1.nil?)
			str += @ch1
		end
		str += "\" />"
		fp.puts(str)

		str = "\t<ch2 yhget=\""
		if (!@ch2.nil?)
			str += @ch2
		end
		str += "\" />"
		fp.puts(str)

		str = "\t<ch3 yhget=\""
		if (!@ch3.nil?)
			str += @ch3
		end
		str += "\" />"
		fp.puts(str)

		str = "\t<ch4 yhget=\""
		if (!@ch4.nil?)
			str += @ch4
		end
		str += "\" />"
		fp.puts(str)

		str = "\t<ch5 yhget=\""
		if (!@ch5.nil?)
			str += @ch5
		end
		str += "\" />"
		fp.puts(str)

		str = "\t<ch6 yhget=\""
		if (!@ch6.nil?)
			str += @ch6
		end
		str += "\" />"
		fp.puts(str)

		str = "\t<ch7 yhget=\""
		if (!@ch7.nil?)
			str += @ch7
		end
		str += "\" />"
		fp.puts(str)

		str = "\t<ch8 yhget=\""
		if (!@ch8.nil?)
			str += @ch8
		end
		str += "\" />"
		fp.puts(str)

		str = "\t<ch9 yhget=\""
		if (!@ch9.nil?)
			str += @ch9
		end
		str += "\" />"
		fp.puts(str)

		str = "\t<ch10 yhget=\""
		if (!@ch10.nil?)
			str += @ch10
		end
		str += "\" />"
		fp.puts(str)

		str = "\t<chr1 yhget=\""
		if (!@chr1.nil?)
			str += @chr1
		end
		str += "\" />"
		fp.puts(str)

		str = "\t<chr2 yhget=\""
		if (!@chr2.nil?)
			str += @chr2
		end
		str += "\" />"
		fp.puts(str)

		str = "\t<chr3 yhget=\""
		if (!@chr3.nil?)
			str += @chr3
		end
		str += "\" />"
		fp.puts(str)

		str = "\t<chr4 yhget=\""
		if (!@chr4.nil?)
			str += @chr4
		end
		str += "\" />"
		fp.puts(str)

		str = "\t<chr5 yhget=\""
		if (!@chr5.nil?)
			str += @chr5
		end
		str += "\" />"
		fp.puts(str)

		str = "\t<chr6 yhget=\""
		if (!@chr6.nil?)
			str += @chr6
		end
		str += "\" />"
		fp.puts(str)

		str = "\t<chr7 yhget=\""
		if (!@chr7.nil?)
			str += @chr7
		end
		str += "\" />"
		fp.puts(str)

		str = "\t<ch11 yhget=\""
		if (!@ch11.nil?)
			str += @ch11
		end
		str += "\" />"
		fp.puts(str)

		str = "\t<paths ps=\""
		if (!$yhpaths.nil?)
			str += $yhpaths
		end
		str += "\" />"
		fp.puts(str)

		str = "\t<pathm pm=\""
		if (!$yhpathm.nil?)
			str += $yhpathm
		end
		str += "\" />"
		fp.puts(str)

		str = "\t<pathc pc=\""
		if (!$yhpathc.nil?)
			str += $yhpathc
		end
		str += "\" />"
		fp.puts(str)

		str = "\t<kaisou chr=\""
		if (!$kaisouchr.nil?)
			str += $kaisouchr
		end
		str += "\" />"
		fp.puts(str)

		str = "\t<ng start=\""
		if (!@ng1.nil?)
			str += @ng1
		end
		str += "\" />"
		fp.puts(str)

		str = "\t<ns end=\""
		if (!@ng2.nil?)
			str += @ng2
		end
		str += "\" />"
		fp.puts(str)

		str = "\t<ds end=\""
		if (!@ds1.nil?)
			str += @ds1
		end
		str += "\" />"
		fp.puts(str)

		str = "\t<di end=\""
		if (!@di1.nil?)
			str += @di1
		end
		str += "\" />"
		fp.puts(str)

		str = "\t<sdir path=\""
		if (!@sdate.nil?)
			str += @sdate
		end
		str += "\" />"
		fp.puts(str)

		fp.puts("</config>")
		fp.close()
	end
end

class SaveDirectoryDialog < QDialog
	def initialize(parent)
		super(parent)

		setCaption(QString::fromUtf8("YahoonewsTTR"))
		bg = QVButtonGroup.new(self)

		bg.setTitle(QString::fromUtf8("各種設定"))
		bg.setGeometry(0,10,400,345)

		@sl3 = QLabel.new(QString::fromUtf8("保存先ディレクトリ"),self)
		@sl0 = QLabel.new(QString::fromUtf8("SD"),self)
		@sl1 = QLabel.new(QString::fromUtf8("本体"),self)
		@sl2 = QLabel.new(QString::fromUtf8("CF"),self)
		@sl3.setGeometry(10,30,190,30)
		@sl0.setGeometry(10,60,50,30)
		@sl1.setGeometry(10,110,50,30)
		@sl2.setGeometry(10,160,50,30)

		@se0 = QLineEdit.new("",self)
		@se0.setGeometry(50,60,320,30)
		@se1 = QLineEdit.new("",self)
		@se1.setGeometry(50,110,320,30)
		@se2 = QLineEdit.new("",self)
		@se2.setGeometry(50,160,320,30)

		@se0.setText(QString::fromUtf8($yhpaths))
		@se1.setText(QString::fromUtf8($yhpathm))
		@se2.setText(QString::fromUtf8($yhpathc))


		@sl4 = QLabel.new(QString::fromUtf8("階層指定文字"),self)
		@sl4.setGeometry(10,200,150,30)

		@se4 = QLineEdit.new("",self)
		@se4.setGeometry(130,200,30,30)

		@se4.setText(QString::fromUtf8($kaisouchr))

		$n1 = QCheckBox.new(QString::fromUtf8("自動接続"),self)
		$n1.setGeometry(10,240,130,30)

		$n2 = QCheckBox.new(QString::fromUtf8("自動切断"),self)
		$n2.setGeometry(150,240,130,30)

		$n3 = QCheckBox.new(QString::fromUtf8("サブフォルダを作成する"),self)
		$n3.setGeometry(10,280,330,30)

		$n4 = QCheckBox.new(QString::fromUtf8("新規取得前に画像ファイルを削除する"),self)
		$n4.setGeometry(10,320,350,30)

		if ( $n1m =~ /true/ ) != nil then
			$n1.setChecked(true)
		end
		if ( $n2m =~ /true/ ) != nil then
			$n2.setChecked(true)
		end
		if ( $n3m =~ /true/ ) != nil then
			$n3.setChecked(true)
		end
		if ( $n4m =~ /true/ ) != nil then
			$n4.setChecked(true)
		end

		okButton = QPushButton.new(QString::fromUtf8("設定"), self)
		okButton.setGeometry(150, 360, 100, 30)

		connect(okButton,QSIGNAL("clicked()"), self, 'gsetpath')
	end

	def gsetpath
		$yhpaths = @se0.text.to_str
		$yhpathm = @se1.text.to_str
		$yhpathc = @se2.text.to_str
		$kaisouchr = @se4.text.to_str

		if $n1.isChecked then
			$n1m = "true"
		else
			$n1m = "false"
		end
		if $n2.isChecked then
			$n2m = "true"
		else
			$n2m = "false"
		end
		if $n3.isChecked then
			$n3m = "true"
		else
			$n3m = "false"
		end
		if $n4.isChecked then
			$n4m = "true"
		else
			$n4m = "false"
		end
		close()
	end
end


class BerryRSSDescViewWidget < BerryBaseWidget
	def initialize(parent)
		super(parent)
		
		@parent = parent

		setCaption(QString::fromUtf8("ダウンロード記事選択"))


		@list = BerryRSSDescViewMultiLineView.new(self)
		@list.setAllColumnsShowFocus(true)
		@list.addColumn(QString::fromUtf8("記事"),QPEApplication.desktop.width - 70)
		@list.addColumn(QString::fromUtf8("Mark"),30)
		@list.setRootIsDecorated(false)
		@list.setMultiSelection(false)
#		@list.setFont QFont.new($fontname,$fontsize,QFont::Bold)

		@list.setColumnAlignment(1,AlignHCenter)

		@Menu1 = QPopupMenu.new()
		@m11 = @Menu1.insertItem(QString::fromUtf8("チェック"), self, "checkitem", Key_D)
		@m12 = @Menu1.insertItem(QString::fromUtf8("取得開始"), self, "gsetpath", CTRL+Key_G)
		@menuBar = QPEMenuBar.new(self)
		@menuBar.insertItem(QString::fromUtf8("Menu"), @Menu1)


		okButton = QPushButton.new(QString::fromUtf8("取得開始( Ctrl + G )"), self)
		
		@widgetLayout = QVBoxLayout.new(self)
		@widgetLayout.addWidget(@menuBar)
		@widgetLayout.addWidget(@list)
		@widgetLayout.addWidget(okButton)


		listshow

		connect(okButton,QSIGNAL("clicked()"), self, 'gsetpath')
		Qte::connect(@list,QSIGNAL("returnPressed(QListViewItem *)"), self, 'checkitem2')
	end

	def screenInit(returnScreenId=Berry::RSS_LIST_WIDGET_ID)
		listshow
	end

	def listshow
		templine = []
		tempname = []
		tname = []
		yhurl = ""
		buf = ""
		ulMode = false
		status = ""
		titleMode = false
		@catename = ""
		@cate_mem = ""
		catemp = ""
		yhoption = "off"
		@list.clear()

		begin
		fp1 = File.open("list_c.txt","r")
		fp1.each do |line|
			if (line =~ /^option yahoonewsTTR on/) != nil then
				yhoption = "on"
			elsif  (line =~ /^option yahoonewsTTR off/) != nil then
				yhoption = "off"
			end
			if (line =~ /^yahoonewsTTR/) != nil then
				if (line =~ /^yahoonewsTTR [a-z]+/) then
				else
					catemp = line.sub(/yahoonewsTTR /,"")
					@catename = Uconv.euctou8(catemp).chomp
					if @catename == @cate_mem then
					else
						@listc = QListViewItem.new(@list,tr(@catename))
					end
				end
			end
			if (line =~ /<title>/) != nil then
				if (line =~ /<\/head>/) then
					catemp = line.sub(/<title>Yahoo.*-  /,"")
					@catename = Uconv.euctou8(catemp.sub(/<\/title><\/head>/,"")).chomp
					if @catename == @cate_mem then
					else
						@listc = QListViewItem.new(@list,tr(@catename))
					end
				end
				titleMode = true
			end
			if (line =~ /<\/title>/) != nil then
				titleMode = false
			end
			if titleMode then
				if (line =~ /<title>/) then
				else
					@catename = Uconv.euctou8(line).chomp
					if @catename == @cate_mem then
					else
						@listc = QListViewItem.new(@list,tr(@catename))
					end
				end
			end
			@cate_mem = @catename
			if ( yhoption =~ /off/ ) != nil then
				if (line =~ /<ul>/) != nil then
					ulMode = true
				end
				if (line =~ /News_ranking_TABLE/) != nil then
					ulMode = true
				end
				if ulMode then
					temp = line .split('"')
					for i in 1..17
						if temp[i] =~ /http:\/\/headline/ then
							tempname = temp[i+1].split('<')
							name = Uconv.euctou8(tempname[0]).split('>')
							QListViewItem.new(@listc,tr(name[1])," ",Uconv.euctou8(temp[i]))
						end
					end
				end
				if (line =~ /<\/ul>/) != nil then
					ulMode = false
				end
				if (line =~ /\/News_ranking_TABLE/) != nil then
					ulMode = false
				end
			else
				if (line =~ /OUTLINE/) != nil then
					ulMode = true
				end
				if (line =~ /news_stories/) != nil then
					ulMode = false
				end
				if ulMode then
					temp = line .split('"')
					if temp[3] =~ /http:\/\/headline/ then
						tempname = temp[4].split('<')
						name = Uconv.euctou8(tempname[0]).split('>')
						QListViewItem.new(@listc,tr(name[1])," ",Uconv.euctou8(temp[3]))
					end
				end

			end
		end
		fp1.close
		fp1 = ""

		@list.setSorting(1,false)
		item = @list.firstChild()
		@list.setCurrentItem(item)
		@list.setFocus()
		rescue
		end
	end

	def checkitem
			item = @list.selectedItem()
			rec = row(item)
			if (rec[1] =~ /DL/ ) then
				item.setText(1,"  ")
			else 
				item.setText(1,"DL")
			end
	end

	def checkitem2(item)
			rec = row(item)
			if (rec[1] =~ /DL/ ) then
				item.setText(1,"  ")
			else 
				item.setText(1,"DL")
			end
	end

	def row(item)
		rec = Array.new(4)
		rec[0] = item.text(0).utf8().to_str()
		rec[1] = item.text(1).utf8().to_str()
		rec[2] = item.text(2).utf8().to_str()
		rec[3] = item.text(3).utf8().to_str()
		return rec
	end

	def gsetpath
		$urllist = []
		allmode = false

		item = @list.firstChild()
		while(!item.nil?)
			itemc = item.firstChild()

			rec = row(item)
			if rec[1] =~ /DL/ then
				allmode = true
			end
			while(!itemc.nil?)
				begin
					if allmode then
						itemc.setText(1,"DL")
					end
					rec = row(itemc)
					if rec[1] =~ /DL/ then
						$urllist.push rec[2]
					end
				rescue
				end
				itemc = itemc.nextSibling()		
			end
			allmode = false
			item = item.nextSibling()
		end
		
		listend
	end

	def listend
		@list.clear()
		$checker = false
		@parent.changeScreen(Berry::RSS_LIST_WIDGET_ID)
		return false
	end

	def close()
		@list.clear()
		$checker = false
		@parent.changeScreen(Berry::RSS_LIST_WIDGET_ID)
		return false
	end

end

class BerryRSSDescViewMultiLineView < QListView
	def initialize(parent)
		super(parent)
		@parent = parent
	end
end


app = QPEApplication.new([$0]+ARGV)
app.setDefaultCodec(QTextCodec::codecForName('utf8'))
QApplication.setFont(QFont.new("lcfont",12,QFont::Bold))
berry = Berry.new()
app.showMainWidget(berry)
app.exec()
